cumulusci.tasks.bulkdata package
================================

.. automodule:: cumulusci.tasks.bulkdata
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

cumulusci.tasks.bulkdata.base\_generate\_data\_task module
----------------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.base_generate_data_task
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.bulkdata.delete module
--------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.delete
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.bulkdata.extract module
---------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.extract
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.bulkdata.factory\_utils module
----------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.factory_utils
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.bulkdata.generate module
----------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.generate
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.bulkdata.generate\_and\_load\_data module
---------------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.generate_and_load_data
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.bulkdata.generate\_and\_load\_data\_from\_yaml module
---------------------------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.generate_and_load_data_from_yaml
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.bulkdata.generate\_from\_yaml module
----------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.generate_from_yaml
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.bulkdata.generate\_mapping module
-------------------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.generate_mapping
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.bulkdata.load module
------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.load
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.bulkdata.utils module
-------------------------------------

.. automodule:: cumulusci.tasks.bulkdata.utils
   :members:
   :undoc-members:
   :show-inheritance:

